==> model-1.2-sources.jar: org/ow2/weblab/core/model/Document.java <==

package org.ow2.weblab.core.model;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * A document is assumed to be a composed unit which
 * 				handle the references of all the unit which have been build on it
 * 				through the multiple processes. As a resource, a document could be
 * 				annotated to provide, for example, meta-information on the original
 * 				document source, the author or the original creation date... Data
 * 				Exchange Model for WebLab platform provided by CASSIDIAN -Version 1.2 -
 * 				2010/08
 * 
 * <p>Java class for Document complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="Document">
 *   &lt;complexContent>
 *     &lt;extension base="{http://weblab.ow2.org/core/1.2/model#}MediaUnit">
 *       &lt;sequence>
 *         &lt;element name="mediaUnit" type="{http://weblab.ow2.org/core/1.2/model#}MediaUnit" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Document", propOrder = {
    "mediaUnit"
})
public class Document
    extends MediaUnit
    implements Serializable
{

    private final static long serialVersionUID = 12L;
    protected List<MediaUnit> mediaUnit;

    /**
     * Gets the value of the mediaUnit property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the mediaUnit property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getMediaUnit().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link MediaUnit }
     * 
     * 
     */
    public List<MediaUnit> getMediaUnit() {
        if (mediaUnit == null) {
            mediaUnit = new ArrayList<MediaUnit>();
        }
        return this.mediaUnit;
    }

    public boolean isSetMediaUnit() {
        return ((this.mediaUnit!= null)&&(!this.mediaUnit.isEmpty()));
    }

    public void unsetMediaUnit() {
        this.mediaUnit = null;
    }

}

==> model-1.2.2-sources.jar: org/ow2/weblab/core/model/Document.java <==

package org.ow2.weblab.core.model;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * A Document is assumed to be a resource which handles the references of all the units that have been built on it through the multiple 
 *             processes. A Document could be annotated to provide, for example, meta-information on the original document source, the author or 
 *             the original creation date... This object is the most commonly exchanged object in usual WebLab-based applications.
 * 
 * 
 * 				Data Exchange Model for WebLab platform provided by CASSIDIAN Version 1.2.1 - 2011/05
 * 
 * <p>Java class for Document complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="Document">
 *   &lt;complexContent>
 *     &lt;extension base="{http://weblab.ow2.org/core/1.2/model#}MediaUnit">
 *       &lt;sequence>
 *         &lt;element name="mediaUnit" type="{http://weblab.ow2.org/core/1.2/model#}MediaUnit" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Document", propOrder = {
    "mediaUnit"
})
public class Document
    extends MediaUnit
    implements Serializable
{

    private final static long serialVersionUID = 121L;
    protected List<MediaUnit> mediaUnit;

    /**
     * Gets the value of the mediaUnit property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the mediaUnit property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getMediaUnit().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link MediaUnit }
     * 
     * 
     */
    public List<MediaUnit> getMediaUnit() {
        if (mediaUnit == null) {
            mediaUnit = new ArrayList<MediaUnit>();
        }
        return this.mediaUnit;
    }

    public boolean isSetMediaUnit() {
        return ((this.mediaUnit!= null)&&(!this.mediaUnit.isEmpty()));
    }

    public void unsetMediaUnit() {
        this.mediaUnit = null;
    }

}
